C+
C NAME:
C	ForeignI4Arg
C PURPOSE:
C	Extract integer*4 value from keyword/value pair
C CALLING SEQUENCE:
	subroutine ForeignI4Arg(cStr,cName,Def,Val)
C INPUTS:
C	cStr		character*(*)	string with keywords
C	cName		character*(*)	name of keyword
C	Def		integer		value assigned if keyword not present
C OUTPUTS:
C	Val		integer		value of keyword
C CALLS:
C	ForeignI4ArgN
C MODIFICATION HISTORY:
C	NOV-2004, Paul Hick (UCSD/CASS)
C	JUN-2006, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C	    Old ForeignI4Arg was used to make ForeignI4ArgN.
C	    New ForeignI4Arg is one-line interface to ForeignI4ArgN
C-
	    character	cStr *(*)
	    character	cName*(*)
	    integer	Def
	    integer	Val

	nVal = 1
	call ForeignI4ArgN(cStr,cName,Def,nVal,Val)

	return
	end
